@@ -14,7 +14,7 @@ use Moose::Util::TypeConstraints;
 
 use HPCD::uni::Run;
 
-with qw(HPCI::Stage);
+with qw(HPCI::Stage), HPCI::get_extra_roles('uni', 'stage');
 
 sub _build_cluster_specific_valid_resources {
 	return (
@@ -72,6 +72,14 @@ sub _analyse_completion_state {
 	$self->_set_state($new_state);
 }
 
+sub _get_submit_timeouts {
+	my $self  = shift;
+	my $res   = $self->_use_resources_required;
+	return
+		$self->_time_to_secs( $res->{s_time} // 0 ),
+		$self->_time_to_secs( $res->{h_time} // 0 );
+}
+
 =head1 AUTHOR
 
 John Macdonald - Boutros Lab
